% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/misc_and_utility.R
\name{umx_check_model}
\alias{umx_check_model}
\title{Check for required features in an OpenMx.}
\usage{
umx_check_model(
  obj,
  type = NULL,
  hasData = NULL,
  beenRun = NULL,
  hasMeans = NULL,
  checkSubmodels = FALSE,
  callingFn = "a function"
)
}
\arguments{
\item{obj}{an object to check}

\item{type}{what type the model must be, i.e., "RAM", "LISREL", etc. (defaults to not checking NULL)}

\item{hasData}{whether the model should have data or not (defaults to not checking NULL)}

\item{beenRun}{whether the model has been run or not (defaults to not checking NULL)}

\item{hasMeans}{whether the model should have a means model or not (defaults to not checking NULL)}

\item{checkSubmodels}{whether to check submodels (not implemented yet) (default = FALSE)}

\item{callingFn}{= Name of the calling function to help the user locate the error.}
}
\value{
- boolean
}
\description{
Allows the user to straight-forwardly require a specific model type (i.e., 
"RAM", "LISREL", etc.), whether or not the model has data, if it has been run or not. 
You can also test whether is has a means model or not and (in future) test if it has submodels.
}
\examples{
\dontrun{
require(umx)
data(demoOneFactor)
manifests = names(demoOneFactor)
m1 = umxRAM("check_model_ex", data = demoOneFactor, type = "cov",
	umxPath("G", to = manifests),
	umxPath(var = manifests),
	umxPath(var = "G", fixedAt = 1)
)
umx_check_model(m1) # TRUE, this is a model
umx_check_model(m1, type = "RAM") # equivalent to umx_is_RAM()
umx_check_model(m1, hasData = TRUE)


umx_check_model(m1, hasMeans = TRUE)
umx_check_model(m1, beenRun = FALSE)
# Model with no data
m1 = umxRAM("x ~~ .3*y", autoRun = FALSE)
umx_check_model(m1, hasData = TRUE)
}
}
\references{
- <https://github.com/tbates/umx>
}
\seealso{
Other Test: 
\code{\link{umx_check_OS}()},
\code{\link{umx_check_names}()},
\code{\link{umx_check_parallel}()},
\code{\link{umx_check}()},
\code{\link{umx_has_CIs}()},
\code{\link{umx_has_been_run}()},
\code{\link{umx_has_means}()},
\code{\link{umx_has_square_brackets}()},
\code{\link{umx_is_MxData}()},
\code{\link{umx_is_MxMatrix}()},
\code{\link{umx_is_MxModel}()},
\code{\link{umx_is_RAM}()},
\code{\link{umx_is_cov}()}
}
\concept{Test}
