% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/misc_and_utility.R
\name{umx_has_CIs}
\alias{umx_has_CIs}
\title{umx_has_CIs}
\usage{
umx_has_CIs(model, check = c("both", "intervals", "output"))
}
\arguments{
\item{model}{The \code{\link[=mxModel]{mxModel()}} to check for presence of CIs}

\item{check}{What to check for: "intervals" requested, "output" present, or "both". Defaults to "both"}
}
\value{
\itemize{
\item TRUE or FALSE
}
}
\description{
A utility function to return a binary answer to the question "does this \code{\link[=mxModel]{mxModel()}} have confidence intervals?"
}
\examples{
\dontrun{
require(umx)
data(demoOneFactor)
manifests = names(demoOneFactor)
m1 = umxRAM("_has_CI_ex", data = demoOneFactor, type = "cov",
	umxPath("g", to = manifests),
	umxPath(var = manifests),
	umxPath(var = "g", fixedAt = 1.0)
)

umx_has_CIs(m1) # FALSE: no CIs and no output
m1 = mxModel(m1, mxCI("g_to_x1"))
umx_has_CIs(m1, check = "intervals") # TRUE intervals set
umx_has_CIs(m1, check = "output")  # FALSE not yet run
m1 = mxRun(m1)
umx_has_CIs(m1, check = "output")  # Still FALSE: Set and Run
m1 = mxRun(m1, intervals = TRUE)
umx_has_CIs(m1, check = "output")  # TRUE: Set, and Run with intervals = T
umxSummary(m1)
}

}
\references{
\itemize{
\item \url{https://github.com/tbates/umx}
}
}
\seealso{
Other Test: 
\code{\link{umx_check_OS}()},
\code{\link{umx_check_model}()},
\code{\link{umx_check_names}()},
\code{\link{umx_check_parallel}()},
\code{\link{umx_check}()},
\code{\link{umx_has_been_run}()},
\code{\link{umx_has_means}()},
\code{\link{umx_has_square_brackets}()},
\code{\link{umx_is_MxData}()},
\code{\link{umx_is_MxMatrix}()},
\code{\link{umx_is_MxModel}()},
\code{\link{umx_is_RAM}()},
\code{\link{umx_is_cov}()}
}
\concept{Test}
